@@ -20,7 +20,8 @@ from openstack_dashboard.api import base
 from openstack_dashboard.api import neutron
 
 from manila_ui.api import manila
-
+from manila_ui.dashboards.project.share_networks.share_network_subnets \
+    import tables as subnet_tables
 
 DELETABLE_STATES = ("INACTIVE", "ERROR")
 EDITABLE_STATES = ("INACTIVE", )
@@ -93,6 +94,14 @@ class UpdateRow(tables.Row):
         return share_net
 
 
+class ShareNetworksFilterAction(tables.FilterAction):
+    filter_type = "server"
+    filter_choices = (
+        ('name', _("Name "), True),
+        ('description', _("Description "), True),
+    )
+
+
 class ShareNetworksTable(tables.DataTable):
     STATUS_CHOICES = (
         ("ACTIVE", True),
@@ -122,7 +131,7 @@ class ShareNetworksTable(tables.DataTable):
         name = "share_networks"
         verbose_name = _("Share Networks")
         table_actions = (
-            tables.NameFilterAction,
+            ShareNetworksFilterAction,
             Create,
             Delete,
         )
@@ -130,4 +139,5 @@ class ShareNetworksTable(tables.DataTable):
         row_actions = (
             EditShareNetwork,
             Delete,
+            subnet_tables.CreateShareNetworkSubnet,
         )
